@@ -1,3 +1,6 @@
+from b4sh.settings import B4SH_DIR
+
+from b4sh import *
 from b4sh.utils import *
 
 
