@@ -4,3 +4,6 @@ from b4sh.utils.helpers import *
 from b4sh.utils.find import *
 from b4sh.utils.get import *
 from b4sh.utils.list import *
+
+import json
+import requests
