@@ -1,4 +1,8 @@
 # To find a b4sh
+import json
+
+from b4sh.settings import HOST
+
 from b4sh.utils import *
 from b4sh.utils import req_get
 from b4sh.utils.get import choose_install
