@@ -180,7 +180,7 @@ def get_format_payload(conf: dict, content_file_path: str = "") -> dict:
     :param content_file_path:
     :return:
     """
-    payload = {"author": conf["author"], "title": rlinput("[?] Title : ", content_file_path),
+    payload = {"author": conf["author"], "title": rlinput("[?] Title : ", content_file_path.replace("./", "")),
                "description": input("[?] Description : ")}
     if len(content_file_path) > 2:
         # we check if the path of the shell file exist
@@ -195,6 +195,8 @@ def get_format_payload(conf: dict, content_file_path: str = "") -> dict:
     else:
         payload["content"] = get_content()
 
+    print("[-] Uploading the b4sh ...")
+
     return payload
 
 
@@ -218,4 +220,4 @@ optional arguments:
   -ls, --list    To list all available offline/local b4sh shells.
 
   -v,  --version To get the actual version of b4sh.
-    """)
\ No newline at end of file
+    """)
